public inbox for [email protected]
help / color / mirror / Atom feedFrom: Aditya Toshniwal <[email protected]>
To: Akshay Joshi <[email protected]>
Cc: pgadmin-hackers <[email protected]>
Subject: Re: pgAdmin 4 commit: Improvement in the look and feel of the whole applica
Date: Thu, 3 Jan 2019 15:50:20 +0530
Message-ID: <CAM9w-_niKinU7MWXxth4Em9BQc=xDKOwgbApL58viZq2zJ=phw@mail.gmail.com> (raw)
In-Reply-To: <CANxoLDeLe0YKm4hZOpwFX79p+DuR0ocibYkH8WFLtk6XwLNK2w@mail.gmail.com>
References: <[email protected]>
<CA+OCxoyp8XjOa0xdiqoohiQ1Bm0fcrruXTWu-Y_mqY5LaGeBoQ@mail.gmail.com>
<CAM9w-_ngsgJxJOJKngc-3W8tqNymKeZjBCuW2_VN-nb4k5du=g@mail.gmail.com>
<CA+OCxoxHWJK+XA6zROKWznJkJf1=adDEoafqCoz9BPnMvmtzAg@mail.gmail.com>
<CA+OCxoyuDXfZR2zNKONy-CWWYbo_xAeLZRVZwVZ=1_gU+4zUAg@mail.gmail.com>
<CAM9w-_mXaptQzE45a3eRfLB5qG0R+qUm6JnAnR4C6rOZ8fiJFw@mail.gmail.com>
<CA+OCxowym3tJZfDkOJkqfsNbaxT=Z=nnxCEQWF4nm+HL5q8_qQ@mail.gmail.com>
<CAM9w-_nXoXLjm4jyJKsZ1vOXJLei7akyrBQMOY+p_jmDzmEmdg@mail.gmail.com>
<CA+OCxow69BHrCT7JcdfVyFwn0JnWEszaMdwxuWaxBddKf=h4mg@mail.gmail.com>
<CAM9w-_myZ=B-Nzt9DGAnvXVQgz3szAbe13cLPC4kSSXbUQXt6w@mail.gmail.com>
<CAM9w-_=sK8X=VXE8mqVY6+McuM=EXwg8_xJ56tf_0pHDvvH7uQ@mail.gmail.com>
<CAM9w-_nkvOB5VTGwLkhDiNUYGF1yho0H6BniUoKFM8vveb3zKg@mail.gmail.com>
<CANxoLDeLe0YKm4hZOpwFX79p+DuR0ocibYkH8WFLtk6XwLNK2w@mail.gmail.com>
Hi Hackers,
Further improvement patch. With this patch, following are fixed:
- Fieldset control design changes
- File dialog - files list header should not scroll with the body and stick
to the top
- Debugger input args dialog cancel button should always be enabled
- Backup globals dialog controls aligmnent correction
- In View Data query tool, explain related buttons should be disabled
- Autocomplete design changes
I have also fixed one issue which was created by the copyright changes in
the file - pgadmin/misc/file_manager/templates/file_manager/js/languages/en.js.
The en.js file contains json data and adding copyright comments to it
caused JSON parsing failure in file dialog. As an improvement, I have
renamed the file from en.js to en.json at all the places to avoid such
changes in future.
Kindly review.
On Wed, Jan 2, 2019 at 3:09 PM Akshay Joshi <[email protected]>
wrote:
> Thanks patch applied.
>
> On Wed, Jan 2, 2019 at 11:23 AM Aditya Toshniwal <
> [email protected]> wrote:
>
>> Hi Hackers,
>>
>> Kindly ignore the previous patch. Attaching updated patch with few more
>> corrections.
>> The patch includes:
>> - Base font size changed from 0.815rem to 0.875rem, for navbar from
>> 0.875rem to 0.925rem.
>> - Dialog sizes made consistent throughout the application. Now there are
>> 3 size options for width and height each - sm, md, lg. Combination of any
>> of these to be used hereafter
>> - Alignment fix for controls of Node properties dialogs which includes
>> showing text and label in one line without dialog size change, checkbox
>> alignment, switch control alignment at places and other minor improvements
>> in other dialogs
>> - Error message design change in dialogs validation
>> - SQL Editor data grid editor popup design changes which were missed
>> - Design change for dashboard server activity grid
>> - Login page language dropdown color fix
>> - Properties accordion collapse design fix
>> - Help, Info icon fixed across all dialogs which were not working if
>> clicked exactly on the text
>> - Added missing icon with buttons at few places
>> - Shadow behind the dialogs is increased to make it look clearly
>> separated and depth.
>> - Control Alignment fix in maintenance dialog
>> - Min height of alertify dialogs set for better UX
>> - File dialog design fix when no files found
>> - Grant wizard fixes - Scroll bar visibility on first page, use full
>> space for SQL generated on the last page
>> - Browser toolbar buttons changed to sync with SQL editor toolbar buttons
>> - Rounded corners for docker floating dialog (no properties)
>> - Renaming file in file dialog should show original file name
>> - SQL data grid text edit popup buttons behaviour was swapped. This is
>> fixed.
>> - Import/Export dialog changes as per new design.
>> - Other improvements wherever noticed.
>>
>> On Tue, Jan 1, 2019 at 11:09 AM Aditya Toshniwal <
>> [email protected]> wrote:
>>
>>> Hi Hackers,
>>>
>>> Attached is the patch to improve the previously committed new design
>>> changes.
>>> The patch includes:
>>> - Base font size changed from 0.815rem to 0.875rem, for navbar from
>>> 0.875rem to 0.925rem.
>>> - Dialog sizes made consistent throughout the application. Now there are
>>> 3 size options for width and height each - sm, md, lg. Combination of any
>>> of these to be used hereafter
>>> - Alignment fix for controls of Node properties dialogs which includes
>>> showing text and label in one line without dialog size change, checkbox
>>> alignment, switch control alignment at places and other minor improvements
>>> in other dialogs
>>> - Error message design change in dialogs validation
>>> - SQL Editor data grid editor popup design changes which were missed
>>> - Design change for dashboard server activity grid
>>> - Login page language dropdown color fix
>>> - Properties accordion collapse design fix
>>> - Help, Info icon fixed across all dialogs which were not working if
>>> clicked exactly on the text
>>> - Added missing icon with buttons at few places
>>> - Shadow behind the dialogs is increased to make it look clearly
>>> separated and depth.
>>> - Control Alignment fix in maintenance dialog
>>> - Min height of alertify dialogs set for better UX
>>> - File dialog design fix when no files found
>>> - Grant wizard fixes - Scroll bar visibility on first page, use full
>>> space for SQL generated on the last page
>>> - Browser toolbar buttons changed to sync with SQL editor toolbar buttons
>>> - Rounded corners for docker floating dialog (no properties)
>>> - Other improvements wherever noticed.
>>>
>>> I hope this covers majority of the issues.
>>> Kindly review.
>>>
>>>
>>> On Fri, Dec 21, 2018 at 7:48 PM Aditya Toshniwal <
>>> [email protected]> wrote:
>>>
>>>>
>>>>
>>>> On Fri, Dec 21, 2018 at 7:46 PM Dave Page <[email protected]> wrote:
>>>>
>>>>> On Fri, Dec 21, 2018 at 2:14 PM Aditya Toshniwal
>>>>> <[email protected]> wrote:
>>>>> >
>>>>> > For the query tool results grid text pop-out, you mean the border
>>>>> size around it ?
>>>>> > We don't have any design discussed for it, so could you please
>>>>> propose what can be done.
>>>>>
>>>>> Border, button colours etc. I can't draw anything, but I'd suggest
>>>>> that the border should be squared not rounded, and the
>>>>> thickness/shadow etc adjusted to match the other styling.
>>>>>
>>>> Cool.
>>>> Button colors are already changed. Others things noted. Will work on
>>>> it.
>>>>
>>>>> >
>>>>> > On Fri, Dec 21, 2018 at 7:35 PM Dave Page <[email protected]> wrote:
>>>>> >>
>>>>> >> On Fri, Dec 21, 2018 at 2:02 PM Aditya Toshniwal
>>>>> >> <[email protected]> wrote:
>>>>> >> >
>>>>> >> >
>>>>> >> >
>>>>> >> > On Fri, Dec 21, 2018 at 7:29 PM Dave Page <[email protected]>
>>>>> wrote:
>>>>> >> >>
>>>>> >> >> One other issue: I'm seeing that standard sized dialogues (e.g.
>>>>> the
>>>>> >> >> Server or Database Properties dialogues) are wrapping their
>>>>> labels and
>>>>> >> >> controls at the default size. That should not be the case.
>>>>> >> >
>>>>> >> > Yep. Akshay has logged that in the sheet shared (
>>>>> https://drive.google.com/open?id=127BgrvdVUvWSEp-GnQvCDx1WaaemsycxSD0aUpWxb6k
>>>>> ).
>>>>> >>
>>>>> >> OK, but the answer isn't to increase the size of the dialogues as
>>>>> >> suggested. The size is fine (though we should review for
>>>>> consistency,
>>>>> >> and ensure we are using no more than 3 default standard sizes
>>>>> >> throughout the app); we should make the controls display nicely on
>>>>> the
>>>>> >> default dialogue size and wrap if the user makes it smaller than we
>>>>> >> can display in.
>>>>> >>
>>>>> >> >> On Fri, Dec 21, 2018 at 12:46 PM Dave Page <[email protected]>
>>>>> wrote:
>>>>> >> >> >
>>>>> >> >> > Hi
>>>>> >> >> >
>>>>> >> >> > On Fri, Dec 21, 2018 at 12:29 PM Aditya Toshniwal
>>>>> >> >> > <[email protected]> wrote:
>>>>> >> >> > >
>>>>> >> >> > > Hi Dave,
>>>>> >> >> > >
>>>>> >> >> > > On Fri, Dec 21, 2018 at 5:51 PM Dave Page <[email protected]>
>>>>> wrote:
>>>>> >> >> > >>
>>>>> >> >> > >> Nice! Thanks Ashesh.
>>>>> >> >> > >>
>>>>> >> >> > >> Some small issues I spotted:
>>>>> >> >> > >>
>>>>> >> >> > >> - The font looks somewhat small. How does it compare in
>>>>> size to, say,
>>>>> >> >> > >> Gmail? I think it needs to be increased to at least that
>>>>> size.
>>>>> >> >> > >
>>>>> >> >> > > Gmail uses 0.875rem (14px) for the left panel (Inbox, Sent).
>>>>> We are using 0.875rem (14px) for main navbar links and 0.815rem(13.04px)
>>>>> for all other text.
>>>>> >> >> >
>>>>> >> >> > Let's increase the default to 0.875, and make the main links
>>>>> >> >> > proportionally bigger.
>>>>> >> >> >
>>>>> >> >> > >> - Dialogues have 2 close buttons next to each other in the
>>>>> top-right.
>>>>> >> >> > >> Looks like an icon and a text version?
>>>>> >> >> > >
>>>>> >> >> > > You need to do a yarn install. wcDocker code is changed to
>>>>> fix that.
>>>>> >> >> >
>>>>> >> >> > Yup, that fixed it.
>>>>> >> >> >
>>>>> >> >> > >> - Why do some Preferences panels use alternate line
>>>>> colouring, whilst
>>>>> >> >> > >> others don't? I suspect it's because some are actually
>>>>> tables under
>>>>> >> >> > >> the hood? I think we need consistency there.
>>>>> >> >> > >
>>>>> >> >> > > Noted.
>>>>> >> >> > >>
>>>>> >> >> > >>
>>>>> >> >> > >> - The Maintenance dialogue looks terrible - it needs to be
>>>>> made much
>>>>> >> >> > >> more compact. I also seem to be getting a failure to create
>>>>> >> >> > >> maintenance jobs (backups etc work fine).
>>>>> >> >> > >
>>>>> >> >> > > Noted.
>>>>> >> >> > >>
>>>>> >> >> > >>
>>>>> >> >> > >> - I think the buttons on the Browser need borders to match
>>>>> other buttons.
>>>>> >> >> > >
>>>>> >> >> > > It is made consistent with other wcDocker buttons like
>>>>> close, right arrow, left arrow. However, we can make it look like other
>>>>> buttons.
>>>>> >> >> >
>>>>> >> >> > I think they're a different class of buttons -
>>>>> control/navigation vs.
>>>>> >> >> > function. I think we should make this change as the browser
>>>>> buttons
>>>>> >> >> > really are a toolbar just like the larger on on the query tool.
>>>>> >> >> >
>>>>> >> >> > Thanks!
>>>>> >> >> >
>>>>> >> >> > >> Thanks!
>>>>> >> >> > >>
>>>>> >> >> > >> On Fri, Dec 21, 2018 at 12:01 PM Ashesh Vashi
>>>>> >> >> > >> <[email protected]> wrote:
>>>>> >> >> > >> >
>>>>> >> >> > >> > Improvement in the look and feel of the whole application
>>>>> >> >> > >> >
>>>>> >> >> > >> > Changed the SCSS/CSS for the below third party libraries
>>>>> to adopt the
>>>>> >> >> > >> > new look 'n' feel:
>>>>> >> >> > >> > - wcDocker
>>>>> >> >> > >> > - Alertify dialogs, and notifications
>>>>> >> >> > >> > - AciTree
>>>>> >> >> > >> > - Bootstrap Navbar
>>>>> >> >> > >> > - Bootstrap Tabs
>>>>> >> >> > >> > - Bootstrap Drop-Down menu
>>>>> >> >> > >> > - Backgrid
>>>>> >> >> > >> > - Select2
>>>>> >> >> > >> >
>>>>> >> >> > >> > Adopated the new the look 'n' feel for the dialogs,
>>>>> wizard, properties,
>>>>> >> >> > >> > tab panels, tabs, fieldset, subnode control, spinner
>>>>> control, HTML
>>>>> >> >> > >> > table, and other form controls.
>>>>> >> >> > >> >
>>>>> >> >> > >> > - Font is changed to Roboto
>>>>> >> >> > >> > - Using SCSS variables to define the look 'n' feel
>>>>> >> >> > >> > - Designer background images for the Login, and Forget
>>>>> password pages in
>>>>> >> >> > >> > 'web' mode
>>>>> >> >> > >> > - Improved the look 'n' feel for the key selection in the
>>>>> preferences
>>>>> >> >> > >> > dialog
>>>>> >> >> > >> > - Table classes consistency changes across the application
>>>>> >> >> > >> > - File Open and Save dialog list view changes
>>>>> >> >> > >> >
>>>>> >> >> > >> > Author(s): Aditya Toshniwal & Khushboo Vashi
>>>>> >> >> > >> >
>>>>> >> >> > >> > Branch
>>>>> >> >> > >> > ------
>>>>> >> >> > >> > master
>>>>> >> >> > >> >
>>>>> >> >> > >> > Details
>>>>> >> >> > >> > -------
>>>>> >> >> > >> >
>>>>> https://git.postgresql.org/gitweb?p=pgadmin4.git;a=commitdiff;h=5799ac14ba17dc25fbec184b3b2c6afbe37f...
>>>>> >> >> > >> >
>>>>> >> >> > >> > Modified Files
>>>>> >> >> > >> > --------------
>>>>> >> >> > >> > web/package.json | 2
>>>>> +-
>>>>> >> >> > >> > .../static/js/fts_configuration.js | 2
>>>>> +-
>>>>> >> >> > >> > .../databases/schemas/functions/__init__.py | 4
>>>>> +-
>>>>> >> >> > >> > .../function => static}/css/function.css | 0
>>>>> >> >> > >> > .../templates/trigger_function/css/function.css | 3
>>>>> -
>>>>> >> >> > >> > .../{templates/edbfunc => static}/css/edbfunc.css | 0
>>>>> >> >> > >> > .../static/js/exclusion_constraint.js | 18
>>>>> +-
>>>>> >> >> > >> > .../foreign_key/static/js/foreign_key.js | 17
>>>>> +-
>>>>> >> >> > >> > .../schemas/tables/rules/static/css/rule.css | 7
>>>>> +
>>>>> >> >> > >> > .../tables/rules/templates/rules/css/rule.css | 8
>>>>> -
>>>>> >> >> > >> > .../databases/schemas/views/static/css/view.css | 7
>>>>> +
>>>>> >> >> > >> > .../schemas/views/templates/mview/css/mview.css | 4
>>>>> -
>>>>> >> >> > >> > .../schemas/views/templates/view/css/view.css | 4
>>>>> -
>>>>> >> >> > >> > .../pgagent/schedules/static/js/pga_schedule.js | 3
>>>>> +-
>>>>> >> >> > >> > .../servers/pgagent/static/css/pga_job.css | 3
>>>>> +
>>>>> >> >> > >> > .../pgagent/templates/pga_job/css/pga_job.css | 13
>>>>> -
>>>>> >> >> > >> > .../server_groups/servers/static/css/servers.css | 4
>>>>> +
>>>>> >> >> > >> > .../server_groups/servers/static/js/server.js | 22
>>>>> +-
>>>>> >> >> > >> > .../server_groups/servers/static/js/variable.js | 4
>>>>> +-
>>>>> >> >> > >> > .../servers/tablespaces/static/js/tablespace.js | 13
>>>>> +-
>>>>> >> >> > >> > .../servers/templates/css/servers.css | 4
>>>>> -
>>>>> >> >> > >> > web/pgadmin/browser/static/css/browser.css | 13
>>>>> -
>>>>> >> >> > >> > web/pgadmin/browser/static/css/wizard.css | 21
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/browser.js | 26
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/collection.js | 16
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/keyboard.js | 14
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/menu.js | 28
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/node.js | 53
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/node.ui.js | 4
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/panel.js | 15
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/js/toolbar.js | 3
>>>>> -
>>>>> >> >> > >> > web/pgadmin/browser/static/js/wizard.js | 58
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/scss/_browser.scss | 43
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/static/scss/_wizard.scss | 41
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/templates/browser/css/node.css | 2
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/browser/templates/browser/index.html | 9
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/dashboard/__init__.py | 2
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/dashboard/static/css/dashboard.css | 21
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/dashboard/static/js/dashboard.js | 120
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/dashboard/static/scss/_dashboard.scss | 44
>>>>> +-
>>>>> >> >> > >> > .../templates/dashboard/database_dashboard.html | 171
>>>>> ++-
>>>>> >> >> > >> > .../templates/dashboard/server_dashboard.html | 197
>>>>> ++-
>>>>> >> >> > >> > .../templates/dashboard/welcome_dashboard.html | 30
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/feature_tests/browser_tool_bar_test.py | 23
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/feature_tests/file_manager_test.py | 23
>>>>> +-
>>>>> >> >> > >> > .../feature_tests/keyboard_shortcut_test.py | 5
>>>>> +-
>>>>> >> >> > >> > .../feature_tests/pg_datatype_validation_test.py | 5
>>>>> +-
>>>>> >> >> > >> > .../pg_utilities_backup_restore_test.py | 28
>>>>> +-
>>>>> >> >> > >> > .../feature_tests/pg_utilities_maintenance_test.py | 16
>>>>> +-
>>>>> >> >> > >> > .../feature_tests/query_tool_journey_test.py | 5
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/feature_tests/query_tool_tests.py | 117
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/feature_tests/view_data_dml_queries.py | 16
>>>>> +-
>>>>> >> >> > >> > .../misc/bgprocess/static/css/bgprocess.css | 11
>>>>> -
>>>>> >> >> > >> > web/pgadmin/misc/bgprocess/static/js/bgprocess.js | 173
>>>>> ++-
>>>>> >> >> > >> > .../misc/bgprocess/static/scss/_bgprocess.scss | 81
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/misc/depends/static/js/depends.js | 3
>>>>> +-
>>>>> >> >> > >> > .../misc/file_manager/static/css/file_manager.css | 141
>>>>> +-
>>>>> >> >> > >> > .../misc/file_manager/static/js/create_dialogue.js | 9
>>>>> +-
>>>>> >> >> > >> > .../misc/file_manager/static/js/select_dialogue.js | 19
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/misc/file_manager/static/js/utility.js | 77
>>>>> +-
>>>>> >> >> > >> > .../file_manager/static/scss/_file_manager.scss | 157
>>>>> +--
>>>>> >> >> > >> > .../file_manager/templates/file_manager/index.html | 95
>>>>> +-
>>>>> >> >> > >> > .../misc/statistics/static/js/statistics.js | 3
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/preferences/static/css/preferences.css | 14
>>>>> -
>>>>> >> >> > >> > web/pgadmin/preferences/static/js/preferences.js | 31
>>>>> +-
>>>>> >> >> > >> > .../preferences/static/scss/_preferences.scss | 16
>>>>> +
>>>>> >> >> > >> > web/pgadmin/static/css/pgadmin.css | 81
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/fonts/Roboto-Bold.ttf | Bin
>>>>> 0 -> 170760 bytes
>>>>> >> >> > >> > web/pgadmin/static/fonts/Roboto-Medium.ttf | Bin
>>>>> 0 -> 172064 bytes
>>>>> >> >> > >> > web/pgadmin/static/fonts/Roboto-Regular.ttf | Bin
>>>>> 0 -> 171676 bytes
>>>>> >> >> > >> > web/pgadmin/static/img/collapse_expand.svg | 15
>>>>> +
>>>>> >> >> > >> > web/pgadmin/static/img/forgot_password.svg | 283
>>>>> ++++
>>>>> >> >> > >> > web/pgadmin/static/img/login.svg | 1
>>>>> +
>>>>> >> >> > >> > web/pgadmin/static/js/alertify.pgadmin.defaults.js | 82
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/js/backform.pgadmin.js | 80
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/js/backgrid.pgadmin.js | 33
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/js/slickgrid/editors.js | 8
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/js/sqleditor/filter_dialog.js | 33
>>>>> +-
>>>>> >> >> > >> > .../static/js/sqleditor/query_tool_preferences.js | 15
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_aci_tree.overrides.scss | 75
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_alert.scss | 12
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_alertify.overrides.scss | 150
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_backform.overrides.scss | 8
>>>>> +
>>>>> >> >> > >> > web/pgadmin/static/scss/_backgrid.overrides.scss | 251
>>>>> +++-
>>>>> >> >> > >> > web/pgadmin/static/scss/_bootstrap.overrides.scss | 230
>>>>> ++--
>>>>> >> >> > >> > web/pgadmin/static/scss/_codemirror.overrides.scss | 94
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_pgadmin.grid.scss | 56
>>>>> +
>>>>> >> >> > >> > web/pgadmin/static/scss/_pgadmin.style.scss | 1440
>>>>> +++++---------------
>>>>> >> >> > >> > web/pgadmin/static/scss/_select2.overrides.scss | 24
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/static/scss/_webcabin.overrides.scss | 368
>>>>> -----
>>>>> >> >> > >> > web/pgadmin/static/scss/_webcabin.pgadmin.scss | 250
>>>>> ++++
>>>>> >> >> > >> > web/pgadmin/static/scss/pgadmin.scss | 10
>>>>> +-
>>>>> >> >> > >> > .../static/scss/resources/_default.style.scss | 90
>>>>> +-
>>>>> >> >> > >> > .../static/scss/resources/_default.variables.scss | 203
>>>>> ++-
>>>>> >> >> > >> > web/pgadmin/static/vendor/backform/backform.js | 645
>>>>> +++++++++
>>>>> >> >> > >> > .../templates/security/change_password.html | 43
>>>>> +-
>>>>> >> >> > >> > .../templates/security/forgot_password.html | 9
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/templates/security/login_user.html | 16
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/templates/security/panel.html | 23
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/backup/__init__.py | 6
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/backup/static/js/backup.js | 8
>>>>> +-
>>>>> >> >> > >> > .../backup/static/js/backup_dialog_wrapper.js | 22
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/datagrid/__init__.py | 1
>>>>> -
>>>>> >> >> > >> > web/pgadmin/tools/datagrid/static/js/datagrid.js | 38
>>>>> +-
>>>>> >> >> > >> > .../tools/datagrid/templates/datagrid/filter.html | 2
>>>>> -
>>>>> >> >> > >> > .../tools/datagrid/templates/datagrid/index.html | 193
>>>>> ++-
>>>>> >> >> > >> > web/pgadmin/tools/debugger/static/css/debugger.css | 34
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/debugger/static/js/debugger.js | 2
>>>>> +-
>>>>> >> >> > >> > .../tools/debugger/static/js/debugger_ui.js | 28
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/debugger/static/js/direct.js | 13
>>>>> +-
>>>>> >> >> > >> > .../tools/debugger/static/scss/_debugger.scss | 8
>>>>> -
>>>>> >> >> > >> > .../tools/debugger/templates/debugger/direct.html | 89
>>>>> +-
>>>>> >> >> > >> > .../tools/grant_wizard/static/js/grant_wizard.js | 27
>>>>> +-
>>>>> >> >> > >> > .../grant_wizard/static/scss/_grant_wizard.scss | 31
>>>>> +-
>>>>> >> >> > >> > .../tools/import_export/static/js/import_export.js | 24
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/maintenance/__init__.py | 10
>>>>> +-
>>>>> >> >> > >> > .../tools/maintenance/static/js/maintenance.js | 24
>>>>> +-
>>>>> >> >> > >> > .../maintenance/static/scss/_maintenance.scss | 2
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/restore/__init__.py | 14
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/restore/static/js/restore.js | 8
>>>>> +-
>>>>> >> >> > >> > .../restore/static/js/restore_dialog_wrapper.js | 24
>>>>> +-
>>>>> >> >> > >> > .../tools/sqleditor/static/css/sqleditor.css | 128
>>>>> +-
>>>>> >> >> > >> > web/pgadmin/tools/sqleditor/static/js/sqleditor.js | 35
>>>>> +-
>>>>> >> >> > >> > .../tools/sqleditor/static/scss/_history.scss | 42
>>>>> +-
>>>>> >> >> > >> > .../tools/sqleditor/static/scss/_sqleditor.scss | 128
>>>>> +-
>>>>> >> >> > >> > .../user_management/static/css/user_management.css | 37
>>>>> -
>>>>> >> >> > >> > .../user_management/static/js/user_management.js | 53
>>>>> +-
>>>>> >> >> > >> > .../static/scss/_user_management.scss | 12
>>>>> +-
>>>>> >> >> > >> > .../javascript/alerts/alertify_wrapper_spec.js | 4
>>>>> +-
>>>>> >> >> > >> > .../backup/backup_dialog_wrapper_spec.js | 8
>>>>> +-
>>>>> >> >> > >> > .../restore/restore_dialog_wrapper_spec.js | 8
>>>>> +-
>>>>> >> >> > >> > web/webpack.config.js | 2
>>>>> +-
>>>>> >> >> > >> > web/webpack.shim.js | 2
>>>>> +-
>>>>> >> >> > >> > web/webpack.test.config.js | 1
>>>>> +
>>>>> >> >> > >> > web/yarn.lock | 1015
>>>>> +++++++++++++-
>>>>> >> >> > >> > 135 files changed, 5002 insertions(+), 3850 deletions(-)
>>>>> >> >> > >> >
>>>>> >> >> > >>
>>>>> >> >> > >>
>>>>> >> >> > >> --
>>>>> >> >> > >> Dave Page
>>>>> >> >> > >> Blog: http://pgsnake.blogspot.com
>>>>> >> >> > >> Twitter: @pgsnake
>>>>> >> >> > >>
>>>>> >> >> > >> EnterpriseDB UK: http://www.enterprisedb.com
>>>>> >> >> > >> The Enterprise PostgreSQL Company
>>>>> >> >> > >
>>>>> >> >> > >
>>>>> >> >> > >
>>>>> >> >> > > --
>>>>> >> >> > > Thanks and Regards,
>>>>> >> >> > > Aditya Toshniwal
>>>>> >> >> > > Software Engineer | EnterpriseDB Software Solutions | Pune
>>>>> >> >> > > "Don't Complain about Heat, Plant a tree"
>>>>> >> >> >
>>>>> >> >> >
>>>>> >> >> >
>>>>> >> >> > --
>>>>> >> >> > Dave Page
>>>>> >> >> > Blog: http://pgsnake.blogspot.com
>>>>> >> >> > Twitter: @pgsnake
>>>>> >> >> >
>>>>> >> >> > EnterpriseDB UK: http://www.enterprisedb.com
>>>>> >> >> > The Enterprise PostgreSQL Company
>>>>> >> >>
>>>>> >> >>
>>>>> >> >>
>>>>> >> >> --
>>>>> >> >> Dave Page
>>>>> >> >> Blog: http://pgsnake.blogspot.com
>>>>> >> >> Twitter: @pgsnake
>>>>> >> >>
>>>>> >> >> EnterpriseDB UK: http://www.enterprisedb.com
>>>>> >> >> The Enterprise PostgreSQL Company
>>>>> >> >
>>>>> >> >
>>>>> >> >
>>>>> >> > --
>>>>> >> > Thanks and Regards,
>>>>> >> > Aditya Toshniwal
>>>>> >> > Software Engineer | EnterpriseDB Software Solutions | Pune
>>>>> >> > "Don't Complain about Heat, Plant a tree"
>>>>> >>
>>>>> >>
>>>>> >>
>>>>> >> --
>>>>> >> Dave Page
>>>>> >> Blog: http://pgsnake.blogspot.com
>>>>> >> Twitter: @pgsnake
>>>>> >>
>>>>> >> EnterpriseDB UK: http://www.enterprisedb.com
>>>>> >> The Enterprise PostgreSQL Company
>>>>> >
>>>>> >
>>>>> >
>>>>> > --
>>>>> > Thanks and Regards,
>>>>> > Aditya Toshniwal
>>>>> > Software Engineer | EnterpriseDB Software Solutions | Pune
>>>>> > "Don't Complain about Heat, Plant a tree"
>>>>>
>>>>>
>>>>>
>>>>> --
>>>>> Dave Page
>>>>> Blog: http://pgsnake.blogspot.com
>>>>> Twitter: @pgsnake
>>>>>
>>>>> EnterpriseDB UK: http://www.enterprisedb.com
>>>>> The Enterprise PostgreSQL Company
>>>>>
>>>>
>>>>
>>>> --
>>>> Thanks and Regards,
>>>> Aditya Toshniwal
>>>> Software Engineer | EnterpriseDB Software Solutions | Pune
>>>> "Don't Complain about Heat, Plant a tree"
>>>>
>>>
>>>
>>> --
>>> Thanks and Regards,
>>> Aditya Toshniwal
>>> Software Engineer | EnterpriseDB Software Solutions | Pune
>>> "Don't Complain about Heat, Plant a tree"
>>>
>>
>>
>> --
>> Thanks and Regards,
>> Aditya Toshniwal
>> Software Engineer | EnterpriseDB Software Solutions | Pune
>> "Don't Complain about Heat, Plant a tree"
>>
>
>
> --
> *Akshay Joshi*
>
> *Sr. Software Architect *
>
>
>
> *Phone: +91 20-3058-9517Mobile: +91 976-788-8246*
>
--
Thanks and Regards,
Aditya Toshniwal
Software Engineer | EnterpriseDB Software Solutions | Pune
"Don't Complain about Heat, Plant a tree"
Attachments:
[application/octet-stream] RM3692.part3.patch (17.3K, 3-RM3692.part3.patch)
download | inline diff:
diff --git a/web/pgadmin/browser/static/js/node.js b/web/pgadmin/browser/static/js/node.js
index 66769223..f5cb8cd0 100644
--- a/web/pgadmin/browser/static/js/node.js
+++ b/web/pgadmin/browser/static/js/node.js
@@ -368,7 +368,7 @@ define('pgadmin.browser.node', [
if (formType == 'fieldset') {
// It is used to show, edit, create the object in the
// properties tab.
- view = new Backform.Fieldset({
+ view = new Backform.Accordian({
el: el,
model: newModel,
schema: fields,
diff --git a/web/pgadmin/misc/file_manager/__init__.py b/web/pgadmin/misc/file_manager/__init__.py
index 1c29b3b0..ec956ea5 100644
--- a/web/pgadmin/misc/file_manager/__init__.py
+++ b/web/pgadmin/misc/file_manager/__init__.py
@@ -221,14 +221,13 @@ def file_manager_js():
mimetype="application/javascript")
[email protected]("/en.js")
[email protected]("/en.json")
@login_required
def language():
"""render the required javascript"""
return Response(response=render_template(
- "file_manager/js/languages/en.js", _=gettext),
- status=200,
- mimetype="application/javascript")
+ "file_manager/js/languages/en.json", _=gettext),
+ status=200)
@blueprint.route("/file_manager_config.js")
diff --git a/web/pgadmin/misc/file_manager/static/scss/_file_manager.scss b/web/pgadmin/misc/file_manager/static/scss/_file_manager.scss
index 2d90a67f..404bf6d1 100644
--- a/web/pgadmin/misc/file_manager/static/scss/_file_manager.scss
+++ b/web/pgadmin/misc/file_manager/static/scss/_file_manager.scss
@@ -5,6 +5,58 @@
.file_listing {
min-width: 100%;
+
+ .file_listing_table {
+ height: 100%;
+ display: block;
+ padding: 0;
+ overflow-y: hidden !important;
+ }
+
+ .file_listing_table thead {
+ display: table;
+ width: 100%;
+ }
+
+ .file_listing_table thead tr {
+ position: relative;
+ display: block;
+ width: 100%;
+ border-bottom: $panel-border;
+ }
+
+ .file_listing_table tbody {
+ display: block;
+ overflow: auto;
+ width: 100%;
+ /* 100% minus thead height */
+ height: calc(100% - 30px);
+ }
+
+ .file_listing_table tbody tr {
+ max-width: 100%;
+ width: 100%;
+ }
+
+ .file_listing_table tbody tr td:nth-child(1),
+ .file_listing_table thead tr th:nth-child(1) {
+ width: 100%;
+ min-width: 100%;
+ }
+
+ .file_listing_table tbody tr td:nth-child(2),
+ .file_listing_table thead tr th:nth-child(2) {
+ width: 100px;
+ min-width: 100px;
+ max-width: 100px;
+ }
+
+ .file_listing_table tbody tr td:nth-child(3),
+ .file_listing_table thead tr th:nth-child(3) {
+ width: 200px;
+ min-width: 200px;
+ max-width: 200px;
+ }
}
.file_listing #contents.grid li:hover,
diff --git a/web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.js b/web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.json
similarity index 84%
rename from web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.js
rename to web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.json
index 65d822f8..cc2b91b4 100644
--- a/web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.js
+++ b/web/pgadmin/misc/file_manager/templates/file_manager/js/languages/en.json
@@ -1,12 +1,3 @@
-/////////////////////////////////////////////////////////////
-//
-// pgAdmin 4 - PostgreSQL Tools
-//
-// Copyright (C) 2013 - 2019, The pgAdmin Development Team
-// This software is released under the PostgreSQL Licence
-//
-//////////////////////////////////////////////////////////////
-
{
"LANGUAGE_FILE_NOT_FOUND": "Language file not found.",
"upload_success": "File uploaded successfully.",
diff --git a/web/pgadmin/static/js/backform.pgadmin.js b/web/pgadmin/static/js/backform.pgadmin.js
index a565edeb..246b30b7 100644
--- a/web/pgadmin/static/js/backform.pgadmin.js
+++ b/web/pgadmin/static/js/backform.pgadmin.js
@@ -38,6 +38,8 @@ define([
setGroupClassName: 'set-group pg-el-12',
tabClassName: 'backform-tab pg-el-12',
setGroupContentClassName: 'fieldset-content pg-el-12',
+ accordianGroupClassName: 'accordian-group pg-el-12',
+ accordianContentClassName: 'accordian-content pg-el-12',
hiddenClassName: 'd-none',
});
@@ -429,12 +431,14 @@ define([
offColor: 'primary',
size: 'small',
},
+ controlLabelClassName: Backform.controlLabelClassName,
+ controlsClassName: Backform.controlsClassName,
extraClasses: [],
helpMessage: null,
},
template: _.template([
- '<label class="<%=Backform.controlLabelClassName%>"><%=label%></label>',
- '<div class="<%=Backform.controlsClassName%>">',
+ '<label class="<%=controlLabelClassName%>"><%=label%></label>',
+ '<div class="<%=controlsClassName%>">',
' <div class="checkbox">',
' <label>',
' <input type="checkbox" class="<%=extraClasses.join(\' \')%>" name="<%=name%>" <%=value ? "checked=\'checked\'" : ""%> <%=disabled ? "disabled" : ""%> <%=required ? "required" : ""%> />',
@@ -636,6 +640,80 @@ define([
},
});
+ Backform.Accordian = Backform.Dialog.extend({
+ className: function() {
+ return 'set-group pg-el-12';
+ },
+ tabPanelClassName: function() {
+ return Backform.tabClassName;
+ },
+ legendClass: 'badge',
+ contentClass: Backform.accordianContentClassName + ' collapse show',
+ template: {
+ 'header': _.template([
+ '<div class="<%=Backform.accordianGroupClassName%>" <%=disabled ? "disabled" : ""%>>',
+ ' <% if (legend != false) { %>',
+ ' <div class="<%=legendClass%>" <%=collapse ? "data-toggle=\'collapse\'" : ""%> data-target="#<%=cId%>"><%=collapse ? "<span class=\'caret\'></span>" : "" %><%=label%></legend>',
+ ' <% } %>',
+ '</div>',
+ ].join('\n')),
+ 'content': _.template(
+ ' <div id="<%= cId %>" class="<%=contentClass%>"></div>'
+ ),
+ },
+ collapse: true,
+ render: function() {
+ this.cleanup();
+
+ var m = this.model,
+ $el = this.$el,
+ tmpl = this.template,
+ controls = this.controls,
+ data = {
+ 'className': _.result(this, 'className'),
+ 'legendClass': _.result(this, 'legendClass'),
+ 'contentClass': _.result(this, 'contentClass'),
+ 'collapse': _.result(this, 'collapse'),
+ },
+ idx = (this.tabIndex * 100),
+ evalF = function(f, d, m) {
+ return (_.isFunction(f) ? !!f.apply(d, [m]) : !!f);
+ };
+
+ this.$el.empty();
+
+ _.each(this.schema, function(o) {
+ idx++;
+ if (!o.version_compatible || !evalF(o.visible, o, m)) {
+ return;
+ }
+
+ if (!o.fields)
+ return;
+
+ var d = _.extend({}, data, o),
+ h = $((tmpl['header'])(d)).appendTo($el),
+ el = $((tmpl['content'])(d)).appendTo(h);
+
+ o.fields.each(function(f) {
+ var cntr = new(f.get('control'))({
+ field: f,
+ model: m,
+ tabIndex: idx,
+ });
+ el.append(cntr.render().$el);
+ controls.push(cntr);
+ });
+ });
+
+ return this;
+ },
+ getValueFromDOM: function() {
+ return '';
+ },
+ events: {},
+ });
+
Backform.Fieldset = Backform.Dialog.extend({
className: function() {
return 'set-group pg-el-12';
@@ -650,7 +728,7 @@ define([
'header': _.template([
'<fieldset class="<%=fieldsetClass%>" <%=disabled ? "disabled" : ""%>>',
' <% if (legend != false) { %>',
- ' <div><legend class="<%=legendClass%>" <%=collapse ? "data-toggle=\'collapse\'" : ""%> data-target="#<%=cId%>"><%=collapse ? "<span class=\'caret\'></span>" : "" %><%=label%></legend></div>',
+ ' <legend class="<%=legendClass%>" <%=collapse ? "data-toggle=\'collapse\'" : ""%> data-target="#<%=cId%>"><%=collapse ? "<span class=\'caret\'></span>" : "" %><%=label%></legend>',
' <% } %>',
'</fieldset>',
].join('\n')),
diff --git a/web/pgadmin/static/scss/_backform.overrides.scss b/web/pgadmin/static/scss/_backform.overrides.scss
index abc2af4e..0a413e37 100644
--- a/web/pgadmin/static/scss/_backform.overrides.scss
+++ b/web/pgadmin/static/scss/_backform.overrides.scss
@@ -48,16 +48,11 @@
}
.backform_control_notes {
- background-color: $color-gray-lighter;
- border: 1px solid $color-gray-light;
- border-radius: 3px;
- color: $color-gray-dark;
- display: block;
+ border: $panel-border;
+ border-radius: $border-radius;
font-family: $font-family-editor;
- font-size: 12px;
- line-height: 1.42857;
+ font-size: 0.8rem;
margin: 0 0 10px;
- overflow: auto;
padding: 5px 10px;
word-wrap: break-word;
}
@@ -69,6 +64,6 @@ div.backform_control_notes label.control-label {
max-width: 90% !important;
}
-.set-group {
+.set-group, .accordian-group {
margin-bottom: $form-group-margin-bottom;
-}
\ No newline at end of file
+}
diff --git a/web/pgadmin/static/scss/_backgrid.overrides.scss b/web/pgadmin/static/scss/_backgrid.overrides.scss
index afe1c65e..e3a3c4ea 100644
--- a/web/pgadmin/static/scss/_backgrid.overrides.scss
+++ b/web/pgadmin/static/scss/_backgrid.overrides.scss
@@ -268,13 +268,18 @@ table.backgrid {
}
.backgrid tbody {
- & td.editor {
+ & td.edit-cell.editor {
background-color: $color-gray-light !important;
border-bottom-color: $color-gray-light !important;
outline: none !important;
}
+ & td.editor {
+ background-color: $color-bg-theme !important;
+ }
+
tr.editor-row {
+ background-color: $color-gray-light !important;
& > td {
padding: 15px !important;
background-color: $color-gray-light !important;
diff --git a/web/pgadmin/static/scss/_codemirror.overrides.scss b/web/pgadmin/static/scss/_codemirror.overrides.scss
index 7fcf18db..70747ced 100644
--- a/web/pgadmin/static/scss/_codemirror.overrides.scss
+++ b/web/pgadmin/static/scss/_codemirror.overrides.scss
@@ -127,18 +127,27 @@
list-style: none;
margin: 0;
- padding: 2px;
+ padding: 0px;
- -webkit-box-shadow: 2px 3px 5px rgba(0,0,0,.2);
- -moz-box-shadow: 2px 3px 5px rgba(0,0,0,.2);
- box-shadow: 2px 3px 5px rgba(0,0,0,.2);
- border-radius: 3px;
- border: 1px solid $border-color;
+ -webkit-box-shadow: $dropdown-box-shadow;
+ -moz-box-shadow: $dropdown-box-shadow;
+ box-shadow: $dropdown-box-shadow;
+ border-radius: $border-radius;
+ border: $panel-border;
- background: $color-bg-theme;
+ background: $sql-hint-bg;
font-size: 90%;
font-family: $font-family-editor;
max-height: 20em;
overflow-y: auto;
-}
+
+ & li {
+ padding: 0.125rem;
+ border-radius: 0rem;
+ &.CodeMirror-hint-active {
+ background: $sql-hint-active-bg;
+ color: $sql-hint-active-fg;
+ }
+ }
+}
\ No newline at end of file
diff --git a/web/pgadmin/static/scss/_pgadmin.style.scss b/web/pgadmin/static/scss/_pgadmin.style.scss
index 0e8ffc7a..3e131848 100644
--- a/web/pgadmin/static/scss/_pgadmin.style.scss
+++ b/web/pgadmin/static/scss/_pgadmin.style.scss
@@ -363,6 +363,10 @@
padding: 5px 10px;
}
+.obj_properties .accordian-group > .accordian-content {
+ padding: 5px 10px;
+}
+
.obj_properties .badge {
display: block;
text-align: left;
@@ -409,15 +413,21 @@
.obj_properties .set-group {
margin: 0.5rem 0rem;
padding: 0rem;
+}
+
+.obj_properties .accordian-group {
+ margin: 0.5rem 0rem;
+ padding: 0rem;
border: $panel-border;
border-radius: $card-border-radius;
- background-color: $color-bg;
+ background-color: $color-bg-theme;
}
fieldset.inline-fieldset {
padding: 10px;
border-radius: $card-border-radius;
background: $color-gray-light;
+ border: $panel-border;
& legend {
font-size: 0.875rem;
font-weight: bold;
diff --git a/web/pgadmin/static/scss/resources/_default.variables.scss b/web/pgadmin/static/scss/resources/_default.variables.scss
index 79eff097..060e915f 100644
--- a/web/pgadmin/static/scss/resources/_default.variables.scss
+++ b/web/pgadmin/static/scss/resources/_default.variables.scss
@@ -174,6 +174,9 @@ $sql-history-success-bg: $color-primary-light;
$sql-history-success-fg: $color-primary;
$sql-history-error-bg: $color-danger-lighter;
$sql-history-error-fg: $color-danger;
+$sql-hint-bg: $color-bg-theme;
+$sql-hint-active-bg: $color-primary;
+$sql-hint-active-fg: $white;
$negative-bg: $color-gray-light;
$dialog-box-shadow: $box-shadow;
diff --git a/web/pgadmin/templates/security/change_password.html b/web/pgadmin/templates/security/change_password.html
index 11f1f438..2de189bc 100644
--- a/web/pgadmin/templates/security/change_password.html
+++ b/web/pgadmin/templates/security/change_password.html
@@ -8,7 +8,7 @@
<div class="col-md-4">
<div class="panel-header h4"><i class="app-icon pg-icon-blue"></i> {{ _('%(appname)s', appname=config.APP_NAME) }}</div>
<div class="panel-body">
- <div class="d-block text-color pb-3 h5">{{ _('Password Change', appname=config.APP_NAME) }}</div>
+ <div class="d-block text-color pb-3 h5">{{ _('Password Change') }}</div>
{% if config.SERVER_MODE %}
<form action="{{ url_for('browser.change_password') }}" method="POST" name="change_password_form">
{{ change_password_form.hidden_tag() }}
diff --git a/web/pgadmin/tools/backup/static/js/backup.js b/web/pgadmin/tools/backup/static/js/backup.js
index c27ca09f..70e8a68b 100644
--- a/web/pgadmin/tools/backup/static/js/backup.js
+++ b/web/pgadmin/tools/backup/static/js/backup.js
@@ -45,8 +45,8 @@ define([
Backform.CustomSwitchControl = Backform.SwitchControl.extend({
template: _.template([
- '<label class="<%=Backform.controlLabelClassName%> custom_switch_label_class"><%=label%></label>',
- '<div class="<%=Backform.controlsClassName%> custom_switch_control_class">',
+ '<label class="<%=controlLabelClassName%> custom_switch_label_class"><%=label%></label>',
+ '<div class="<%=controlsClassName%> custom_switch_control_class">',
' <div class="checkbox">',
' <label>',
' <input type="checkbox" class="<%=extraClasses.join(\' \')%>"',
@@ -93,6 +93,7 @@ define([
type: 'nested',
control: 'fieldset',
label: gettext('Miscellaneous'),
+ contentClass: 'row',
schema: [{
id: 'verbose',
label: gettext('Verbose messages'),
@@ -105,6 +106,8 @@ define([
control: Backform.CustomSwitchControl,
disabled: false,
group: gettext('Miscellaneous'),
+ controlLabelClassName: 'control-label pg-el-sm-6 pg-el-12',
+ controlsClassName: 'pgadmin-controls pg-el-sm-6 pg-el-12',
}],
}, {
id: 'globals_note',
diff --git a/web/pgadmin/tools/debugger/static/js/debugger_ui.js b/web/pgadmin/tools/debugger/static/js/debugger_ui.js
index 90177b6b..921813df 100644
--- a/web/pgadmin/tools/debugger/static/js/debugger_ui.js
+++ b/web/pgadmin/tools/debugger/static/js/debugger_ui.js
@@ -949,7 +949,7 @@ define([
this.grid.listenTo(this.debuggerInputArgsColl, 'backgrid:error',
(function(obj) {
return function() {
- obj.__internal.buttons[0].element.disabled = true;
+ obj.__internal.buttons[1].element.disabled = true;
};
})(this)
);
diff --git a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
index be957b44..0bba2b38 100644
--- a/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
+++ b/web/pgadmin/tools/sqleditor/static/js/sqleditor.js
@@ -3435,6 +3435,9 @@ define('tools.querytool', [
disable_tool_buttons: function(disabled) {
$('#btn-clear').prop('disabled', disabled);
$('#btn-query-dropdown').prop('disabled', disabled);
+ $('#btn-explain').prop('disabled', disabled);
+ $('#btn-explain-analyze').prop('disabled', disabled);
+ $('#btn-explain-options-dropdown').prop('disabled', disabled);
$('#btn-edit-dropdown').prop('disabled', disabled);
$('#btn-edit').prop('disabled', disabled);
$('#btn-load-file').prop('disabled', disabled);
view thread (29+ messages) latest in thread
reply
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: [email protected]
Cc: [email protected], [email protected], [email protected]
Subject: Re: pgAdmin 4 commit: Improvement in the look and feel of the whole applica
In-Reply-To: <CAM9w-_niKinU7MWXxth4Em9BQc=xDKOwgbApL58viZq2zJ=phw@mail.gmail.com>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by agora; see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/web/pgadmin/misc/file_manager/static/js/utility.js b/web/pgadmin/misc/file_manager/static/js/utility.js
index d9ed297e..ae6b8b34 100644
--- a/web/pgadmin/misc/file_manager/static/js/utility.js
+++ b/web/pgadmin/misc/file_manager/static/js/utility.js
@@ -36,7 +36,7 @@ define([
};
/* Common function to load:
* en.js language file
* file_manager_config.js config file
* return transaction id
*/
@@ -585,7 +585,7 @@ define([
result += '</ul>';
} else {
- result += '<table id="contents" class="table table-bordered table-noouter-border table-bottom-border table-hover tablesorter">';
+ result += '<table id="contents" class="table table-bordered table-noouter-border table-bottom-border table-hover tablesorter file_listing_table">';
result += '<thead><tr><th>';
result += '<span>' + lg.name + '</span></th>';
result += '<th><span>' + lg.size + '</span></th><th>';
@@ -1096,8 +1096,8 @@ define([
*/
var lg = [],
- enjs = url_for('file_manager.index') + 'en.js',
- lgf = loadData(enjs);
+ enjson = url_for('file_manager.index') + 'en.json',
+ lgf = loadData(enjson);
if (lgf.readyState == 4) {
this.lg = lg = JSON.parse(lgf.responseText);
@@ -36,7 +36,7 @@ define([
};
/* Common function to load:
- * en.js language file
+ * en.json language file
* file_manager_config.js config file
* return transaction id